object

package
v0.0.0-...-cd7a621 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 16, 2022 License: Apache-2.0 Imports: 4 Imported by: 0

Documentation

Overview

Copyright 2022 The casbin Authors. All Rights Reserved.

Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at

http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.

Copyright 2022 The casbin Authors. All Rights Reserved.

Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at

http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type RequestState

type RequestState interface {
	AddRequest(req *http.Request) int
	GetRequest(state int) (*http.Request, error)
	DeleteRequest(state int) error
}

func NewRequestStateMem

func NewRequestStateMem() RequestState

type RequestStateMem

type RequestStateMem struct {
	sync.Mutex
	// contains filtered or unexported fields
}

func (*RequestStateMem) AddRequest

func (r *RequestStateMem) AddRequest(req *http.Request) int

func (*RequestStateMem) DeleteRequest

func (r *RequestStateMem) DeleteRequest(state int) error

func (*RequestStateMem) GetRequest

func (r *RequestStateMem) GetRequest(state int) (*http.Request, error)

Jump to